@@ -9,8 +9,8 @@
 #ifndef KFINDDIALOG_P_H
 #define KFINDDIALOG_P_H
 
-#include "kfinddialog.h"
 #include "kfind.h"
+#include "kfinddialog.h"
 
 #include <QStringList>
 
@@ -23,37 +23,41 @@ class QGroupBox;
 class QMenu;
 class QPushButton;
 
-class Q_DECL_HIDDEN KFindDialog::KFindDialogPrivate
+class KFindDialogPrivate
 {
+    Q_DECLARE_PUBLIC(KFindDialog)
+
 public:
     KFindDialogPrivate(KFindDialog *q)
-        : q(q),
-          regexpDialog(nullptr),
-          regexpDialogQueryDone(false),
-          initialShowDone(false),
-          enabled(KFind::WholeWordsOnly | KFind::FromCursor |  KFind::SelectedText | KFind::CaseSensitive | KFind::FindBackwards | KFind::RegularExpression),
-          findExtension(nullptr),
-          buttonBox(nullptr)
-    {}
+        : q_ptr(q)
+        , regexpDialog(nullptr)
+        , regexpDialogQueryDone(false)
+        , initialShowDone(false)
+        , enabled(KFind::WholeWordsOnly | KFind::FromCursor | KFind::SelectedText | KFind::CaseSensitive | KFind::FindBackwards | KFind::RegularExpression)
+        , findExtension(nullptr)
+        , buttonBox(nullptr)
+    {
+    }
+    virtual ~KFindDialogPrivate() = default;
 
     void init(bool forReplace, const QStringList &findStrings, bool hasSelection);
 
-    void _k_slotPlaceholdersAboutToShow();
-    void _k_slotOk();
-    void _k_slotReject();
-    void _k_slotSelectedTextToggled(bool);
-    void _k_showPatterns();
-    void _k_showPlaceholders();
-    void _k_textSearchChanged(const QString &);
+    void slotPlaceholdersAboutToShow();
+    void slotOk();
+    void slotReject();
+    void slotSelectedTextToggled(bool);
+    void showPatterns();
+    void showPlaceholders();
+    void textSearchChanged(const QString &);
 
-    KFindDialog *q = nullptr;
+    KFindDialog *const q_ptr = nullptr;
     QDialog *regexpDialog = nullptr;
     bool regexpDialogQueryDone : 1;
     bool initialShowDone : 1;
     long enabled; // uses Options to define which search options are enabled
     QStringList findStrings;
     QString pattern;
-    QWidget *findExtension = nullptr;
+    mutable QWidget *findExtension = nullptr;
     QDialogButtonBox *buttonBox = nullptr;
 
     QGroupBox *findGrp = nullptr;
