@@ -1,20 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2002 Carsten Pfeiffer <pfeiffer@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KTEXTEDIT_H
@@ -22,11 +10,17 @@
 
 #include "ktextwidgets_export.h"
 
-#include <sonnet/highlighter.h>
 #include <QTextEdit>
-namespace Sonnet {
+#include <memory>
+#include <sonnet/highlighter.h>
+
+namespace Sonnet
+{
 class SpellCheckDecorator;
 }
+
+class KTextEditPrivate;
+
 /**
  * @class KTextEdit ktextedit.h <KTextEdit>
  *
@@ -48,7 +42,7 @@ class SpellCheckDecorator;
  * @see QTextEdit
  * @author Carsten Pfeiffer <pfeiffer@kde.org>
  */
-class KTEXTWIDGETS_EXPORT KTextEdit : public QTextEdit //krazy:exclude=qclasses
+class KTEXTWIDGETS_EXPORT KTextEdit : public QTextEdit // krazy:exclude=qclasses
 {
     Q_OBJECT
 #if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 0)
@@ -195,7 +189,10 @@ public:
      * @deprecated since 5.0, use QTextEdit::setPlaceholderText instead
      */
     KTEXTWIDGETS_DEPRECATED_VERSION(5, 0, "Use QTextEdit::setPlaceholderText(const QString&)")
-    inline void setClickMessage(const QString &msg) {setPlaceholderText(msg);}
+    inline void setClickMessage(const QString &msg)
+    {
+        setPlaceholderText(msg);
+    }
 #endif
 
 #if KTEXTWIDGETS_ENABLE_DEPRECATED_SINCE(5, 0)
@@ -204,7 +201,10 @@ public:
      * @deprecated since 5.0, use QTextEdit::placeholderText instead
      */
     KTEXTWIDGETS_DEPRECATED_VERSION(5, 0, "Use QTextEdit::placeholderText()")
-    inline QString clickMessage() const {return placeholderText();}
+    inline QString clickMessage() const
+    {
+        return placeholderText();
+    }
 #endif
 
     /**
@@ -384,21 +384,16 @@ protected:
      */
     void contextMenuEvent(QContextMenuEvent *) override;
 
-private:
-    class Private;
-    Private *const d;
+protected:
+    KTextEdit(KTextEditPrivate &dd, const QString &text, QWidget *parent);
+    KTextEdit(KTextEditPrivate &dd, QWidget *parent);
 
-    Q_PRIVATE_SLOT(d, void spellCheckerMisspelling(const QString &, int))
-    Q_PRIVATE_SLOT(d, void spellCheckerCorrected(const QString &, int, const QString &))
-    Q_PRIVATE_SLOT(d, void spellCheckerCanceled())
-    Q_PRIVATE_SLOT(d, void spellCheckerAutoCorrect(const QString &, const QString &))
-    Q_PRIVATE_SLOT(d, void spellCheckerFinished())
-    Q_PRIVATE_SLOT(d, void undoableClear())
-    Q_PRIVATE_SLOT(d, void toggleAutoSpellCheck())
-    Q_PRIVATE_SLOT(d, void slotAllowTab())
-    Q_PRIVATE_SLOT(d, void menuActivated(QAction *))
-    Q_PRIVATE_SLOT(d, void slotFindHighlight(const QString &, int, int))
-    Q_PRIVATE_SLOT(d, void slotReplaceText(const QString &, int, int, int))
+private:
+    friend class KRichTextEdit;
+    friend class KRichTextWidget;
+    Q_DECLARE_PRIVATE_D(d, KTextEdit)
+    std::unique_ptr<class KTextEditPrivate> const d;
+    // KF6 TODO: change private d to protected d_ptr, use normal Q_DECLARE_PRIVATE, remove friend
 };
 
 #endif // KTEXTEDIT_H
